summaryrefslogtreecommitdiff
path: root/include/clang/Sema/LoopHint.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/clang/Sema/LoopHint.h')
-rw-r--r--include/clang/Sema/LoopHint.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/include/clang/Sema/LoopHint.h b/include/clang/Sema/LoopHint.h
index d4b985df544c..c8b2ee845e59 100644
--- a/include/clang/Sema/LoopHint.h
+++ b/include/clang/Sema/LoopHint.h
@@ -26,13 +26,18 @@ struct LoopHint {
// hints.
IdentifierLoc *PragmaNameLoc;
// Name of the loop hint. Examples: "unroll", "vectorize". In the
- // "#pragma unroll" case, this is identical to PragmaNameLoc.
+ // "#pragma unroll" and "#pragma nounroll" cases, this is identical to
+ // PragmaNameLoc.
IdentifierLoc *OptionLoc;
- // Identifier for the hint argument. If null, then the hint has no argument
- // such as for "#pragma unroll".
- IdentifierLoc *ValueLoc;
+ // Identifier for the hint state argument. If null, then the state is
+ // default value such as for "#pragma unroll".
+ IdentifierLoc *StateLoc;
// Expression for the hint argument if it exists, null otherwise.
Expr *ValueExpr;
+
+ LoopHint()
+ : PragmaNameLoc(nullptr), OptionLoc(nullptr), StateLoc(nullptr),
+ ValueExpr(nullptr) {}
};
} // end namespace clang